<?php

namespace EventPortal\Domain\Table\Factories;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\Relation;

class TableJoiner
{
    public static function join(Builder $query, Relation $relation): Builder
    {
        if ($relation instanceof BelongsTo) {
            self::joinBelongsTo($query, $relation);
        }

        return $query;
    }

    private static function joinBelongsTo(Builder $query, Relation $relation): void
    {
        $relatedTable = $relation->getRelated()->getTable();
        [$ownerKey, $foreignKey, $parentTable] = (function () {
            return [$this->ownerKey, $this->foreignKey, $this->child->getTable()];
        })->call($relation);

        $query->join($relatedTable, function ($join) use ($relatedTable, $ownerKey, $foreignKey, $parentTable) {
            return $join->on($relatedTable . '.' . $ownerKey, '=', $parentTable . '.' . $foreignKey);
        });
    }
}
