<?php

namespace EventPortal\Http\Controllers\Admin\EventDelegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Eloquent\Builder;
use Inertia\Inertia;
use Inertia\Response;

class DelegatesNotOnEventController extends Controller
{
    public function index(Event $event): Response
    {
        $table = Table::make('event-delegate.add')
            ->context($event)
            ->query(Delegate::whereDoesntHave('events', function (Builder $query) use ($event): Builder {
                return $query->where('events.id', '=', $event->id);
            }))
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Delegates', route('admin.event.delegate.index', $event))
            ->add('Add Delegates')
            ->get();

        return Inertia::render('EventDelegate/Add', [
            'data' => $table,
            'event' => $event,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => 'Add Delegates',
        ]);
    }
}
